==> vscat-1.0.0.tgz: package/tests/highlighting/diagnostics/html/tag-warning/results/output.red.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`diagnostics suite html language tag-warning test red theme 1`] = `
Object {
  "lines": Array [
    "[48;2;57;0;0m [38;2;135;63;63m 1 │ [39m[38;2;235;13;30m<html>[39m                                                                    [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 2 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;235;13;30m<head>[39m                                                                  [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 3 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;235;13;30m<meta[39m[38;2;193;0;0m·[39m[38;2;235;13;30mfoo=[39m[38;2;204;140;140m\\"bar\\"[39m[38;2;193;0;0m·[39m[38;2;235;13;30m/>[39m                                                    [49m",
    "[48;2;57;0;0m   [38;2;135;63;63m │ [39m[38;2;193;0;0m [39m[38;2;193;0;0m [39m[38;2;193;0;0m [39m[38;2;193;0;0m [39m[38;2;193;0;0m [39m[38;2;193;0;0m [39m[38;2;193;0;0m [39m[38;2;193;0;0m [39m[38;2;193;0;0m [39m[38;2;193;0;0m [39m[38;2;204;167;0m~~~[39m                                                             [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 4 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;235;13;30m<meta[39m[38;2;193;0;0m·[39m[38;2;235;13;30mcharset=[39m[38;2;204;140;140m\\"utf-8\\"[39m[38;2;193;0;0m·[39m[38;2;235;13;30m/>[39m                                              [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 5 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;235;13;30m<title>[39m[38;2;248;248;248mmy[39m[38;2;193;0;0m·[39m[38;2;248;248;248mpage[39m[38;2;235;13;30m</title>[39m                                                [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 6 │ #EB0D1E │ <html>
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #F8F8F8 │   
 1 │  2, 8 │ #EB0D1E │ <head>
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 4 │ #F8F8F8 │     
 2 │  4,14 │ #EB0D1E │ <meta foo=
 2 │ 14,19 │ #CC8C8C │ \\"bar\\"
 2 │ 19,22 │ #EB0D1E │  />
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 4 │ #F8F8F8 │     
 3 │  4,18 │ #EB0D1E │ <meta charset=
 3 │ 18,25 │ #CC8C8C │ \\"utf-8\\"
 3 │ 25,28 │ #EB0D1E │  />
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 4 │ #F8F8F8 │     
 4 │  4,11 │ #EB0D1E │ <title>
 4 │ 11,18 │ #F8F8F8 │ my page
 4 │ 18,26 │ #EB0D1E │ </title>
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #F8F8F8 │   
 5 │  2, 9 │ #EB0D1E │ </head>
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #F8F8F8 │   
 6 │  2, 8 │ #EB0D1E │ <body>
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0,11 │ #F8F8F8 │     Content
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 2 │ #F8F8F8 │   
 8 │  2, 9 │ #EB0D1E │ </body>
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 7 │ #EB0D1E │ </html>
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/diagnostics/html/tag-warning/results/output.red.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`diagnostics suite html language tag-warning test red theme 1`] = `
Object {
  "lines": Array [
    "[48;2;57;0;0m [38;2;135;63;63m 1 │ [39m[38;2;235;13;30m<html>[39m                                                                    [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 2 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;235;13;30m<head>[39m                                                                  [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 3 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;235;13;30m<meta[39m[38;2;193;0;0m·[39m[38;2;235;13;30mfoo=[39m[38;2;204;140;140m\\"bar\\"[39m[38;2;193;0;0m·[39m[38;2;235;13;30m/>[39m                                                    [49m",
    "[48;2;57;0;0m   [38;2;135;63;63m │ [39m[38;2;248;248;248m          [39m[38;2;204;167;0m~~~[39m                                                             [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 4 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;235;13;30m<meta[39m[38;2;193;0;0m·[39m[38;2;235;13;30mcharset=[39m[38;2;204;140;140m\\"utf-8\\"[39m[38;2;193;0;0m·[39m[38;2;235;13;30m/>[39m                                              [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 5 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;235;13;30m<title>[39m[38;2;248;248;248mmy[39m[38;2;193;0;0m·[39m[38;2;248;248;248mpage[39m[38;2;235;13;30m</title>[39m                                                [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 6 │ #EB0D1E │ <html>
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #F8F8F8 │   
 1 │  2, 8 │ #EB0D1E │ <head>
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 4 │ #F8F8F8 │     
 2 │  4,14 │ #EB0D1E │ <meta foo=
 2 │ 14,19 │ #CC8C8C │ \\"bar\\"
 2 │ 19,22 │ #EB0D1E │  />
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 4 │ #F8F8F8 │     
 3 │  4,18 │ #EB0D1E │ <meta charset=
 3 │ 18,25 │ #CC8C8C │ \\"utf-8\\"
 3 │ 25,28 │ #EB0D1E │  />
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 4 │ #F8F8F8 │     
 4 │  4,11 │ #EB0D1E │ <title>
 4 │ 11,18 │ #F8F8F8 │ my page
 4 │ 18,26 │ #EB0D1E │ </title>
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #F8F8F8 │   
 5 │  2, 9 │ #EB0D1E │ </head>
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #F8F8F8 │   
 6 │  2, 8 │ #EB0D1E │ <body>
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0,11 │ #F8F8F8 │     Content
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 2 │ #F8F8F8 │   
 8 │  2, 9 │ #EB0D1E │ </body>
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 7 │ #EB0D1E │ </html>
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │ none  │         │
",
  ],
}
`;
